.. MicroStructPy documentation master file, created by
   sphinx-quickstart on Tue Apr 24 19:06:13 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to AABBTree!
=========================

.. include:: ../../README.rst
  :start-line: 2
  :end-before: Documentation

API
===

.. include:: aabb.rst
  :start-line: 2


Contributing
============

.. include:: ../../README.rst
  :start-after: Contributing

.. admonition:: License

  .. include:: ../../LICENSE.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
